#define GL_GLEXT_PROTOTYPES
#include <QGLWidget>
#include "myglwidget.h"
#include <iostream>
#include <QTimer>
#include "scene.h"
#include "transformnode.h"
#include <QContextMenuEvent>
#include <QMenu>

MyGLWidget::MyGLWidget(QWidget *parent) : QGLWidget(parent)
{
    red = 1.0;
    green = 1.0;
    blue = 0.0;

    i = 0.0;


    actionRed = new QAction(QString::fromUtf8("Focus red box"), this);
    connect(actionRed, SIGNAL(triggered()), this, SLOT(focusRed()));

    actionBlue = new QAction(QString::fromUtf8("Focus blue box"), this);
    connect(actionBlue, SIGNAL(triggered()), this, SLOT(focusBlue()));
}

void MyGLWidget::setScene(Scene *scene)
{
    this->scene = scene;
}

void MyGLWidget::focusRed()
{
    std::cout << "RED" << std::endl;
    scene->focus("Rot");
    updateGL();
}

void MyGLWidget::focusBlue()
{
    std::cout << "BLUE" << std::endl;
    scene->focus("Blau");
    updateGL();
}

void MyGLWidget::rotateX(int val)
{
    scene->rotateCamX(val);
    updateGL();
}

void MyGLWidget::rotateY(int val)
{
    scene->rotateCamY(val);
    updateGL();
}

void MyGLWidget::rotateZ(int val)
{
    scene->rotateCamZ(val);
    updateGL();
}

void MyGLWidget::contextMenuEvent(QContextMenuEvent *event)
{
    QMenu menu(this);
    menu.addAction(actionBlue);
    menu.addAction(actionRed);

    menu.exec(event->globalPos());
}

void MyGLWidget::initializeGL(){
    glClearColor(red, green, blue, 1.0);
    glShadeModel(GL_SMOOTH);
    glEnable(GL_DEPTH_TEST);
    glEnable(GL_CULL_FACE);
}
void MyGLWidget::paintGL(){
    glClearColor(red, green, blue, 1.0);
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    glMatrixMode(GL_MODELVIEW);
    glLoadIdentity();
    scene->render();


}
void MyGLWidget::resizeGL(int width, int height){
    glViewport(0,0, width, height);
    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
//    glFrustum(-1, +1, -1, +1, 1.0, 60.0);
    gluPerspective(60.f, width/static_cast<float>(height), 0.1, 60);
    glMatrixMode(GL_MODELVIEW);
    glLoadIdentity();
}

MyGLWidget::~MyGLWidget()
{
    delete scene;
}
